@@ -195,45 +195,6 @@ void babl_store_db (void)
   free (tmpp);
 }
 
-static int
-babl_file_get_contents (const char  *path,
-                        char       **contents,
-                        long        *length,
-                        void        *error)
-{
-  FILE *file;
-  long  size;
-  char *buffer;
-
-  file = fopen (path,"rb");
-
-  if (!file)
-    return -1;
-
-  fseek (file, 0, SEEK_END);
-  size = ftell (file);
-  if (length) *length = size;
-  rewind (file);
-  buffer = malloc(size + 8);
-
-  if (!buffer)
-    {
-      fclose(file);
-      return -1;
-    }
-
-  size -= fread (buffer, 1, size, file);
-  if (size)
-    {
-      fclose (file);
-      free (buffer);
-      return -1;
-    }
-  fclose (file);
-  *contents = buffer;
-  return 0;
-}
-
 int
 _babl_fish_path_destroy (void *data);
 
@@ -259,7 +220,7 @@ void babl_init_db (void)
   if (getenv ("BABL_DEBUG_CONVERSIONS"))
     return;
 
-  babl_file_get_contents (path, &contents, &length, NULL);
+  _babl_file_get_contents (path, &contents, &length, NULL);
   if (!contents)
     return;
 
@@ -296,7 +257,7 @@ void babl_init_db (void)
           }
           break;
         case '\t':
-          if (strchr (token, '='))
+          if (to_format && strchr (token, '='))
           {
             char seps2[] = " ";
             char *tokp2;
@@ -346,7 +307,7 @@ void babl_init_db (void)
               token2 = strtok_r (NULL, seps2, &tokp2);
             }
           }
-          else
+          else if (to_format)
           {
             Babl *conv = (void*)babl_db_find(babl_conversion_db(), &token[1]);
             if (!conv)
@@ -361,14 +322,10 @@ void babl_init_db (void)
           if (!from_format)
           {
             from_format = (void*)babl_db_find(babl_format_db(), token);
-            if (!from_format)
-              return;
           }
           else
           {
             to_format = (void*)babl_db_find(babl_format_db(), token);
-            if (!to_format)
-              return;
           }
           break;
       }
