@@ -21,19 +21,23 @@
 #include <stdint.h>
 #include <stdlib.h>
 
-#include "babl.h"
+#include "babl-internal.h"
 #include "babl-cpuaccel.h"
 #include "extensions/util.h"
 #include "base/util.h"
 
+
 #define INLINE inline
 
 
-static INLINE long
-conv_rgbaF_linear_rgbAF_gamma (unsigned char *src, 
-                               unsigned char *dst, 
+static INLINE void
+conv_rgbaF_linear_rgbAF_gamma (const Babl *conversion,unsigned char *src,
+                               unsigned char *dst,
                                long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
+
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
@@ -41,19 +45,22 @@ conv_rgbaF_linear_rgbAF_gamma (unsigned char *src,
    while (n--)
      {
        float alpha = fsrc[3];
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++) * alpha;
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++) * alpha;
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++) * alpha;
+       *fdst++ = babl_trc_from_linear (trc[0], *fsrc++) * alpha;
+       *fdst++ = babl_trc_from_linear (trc[1], *fsrc++) * alpha;
+       *fdst++ = babl_trc_from_linear (trc[2], *fsrc++) * alpha;
        *fdst++ = *fsrc++;
      }
-  return samples;
 }
 
-static INLINE long
-conv_rgbAF_linear_rgbAF_gamma (unsigned char *src, 
-                               unsigned char *dst, 
+static INLINE void
+conv_rgbAF_linear_rgbAF_gamma (const Babl    *conversion,
+                               unsigned char *src,
+                               unsigned char *dst,
                                long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
+
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
@@ -71,96 +78,100 @@ conv_rgbAF_linear_rgbAF_gamma (unsigned char *src,
          }
        else if (alpha >= 1.0)
          {
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
+           *fdst++ = babl_trc_from_linear (trc[0], *fsrc++) * alpha;
+           *fdst++ = babl_trc_from_linear (trc[1], *fsrc++) * alpha;
+           *fdst++ = babl_trc_from_linear (trc[2], *fsrc++) * alpha;
            *fdst++ = *fsrc++;
          }
        else
          {
            float alpha_recip = 1.0 / alpha;
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++ * alpha_recip) * alpha;
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++ * alpha_recip) * alpha;
-           *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++ * alpha_recip) * alpha;
+           *fdst++ = babl_trc_from_linear (trc[0], *fsrc++ * alpha_recip) * alpha;
+           *fdst++ = babl_trc_from_linear (trc[1], *fsrc++ * alpha_recip) * alpha;
+           *fdst++ = babl_trc_from_linear (trc[2], *fsrc++ * alpha_recip) * alpha;
            *fdst++ = *fsrc++;
          }
      }
-  return samples;
 }
 
-static INLINE long
-conv_rgbaF_linear_rgbaF_gamma (unsigned char *src, 
+static INLINE void
+conv_rgbaF_linear_rgbaF_gamma (const Babl *conversion,unsigned char *src, 
                                unsigned char *dst, 
                                long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
+
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
 
    while (n--)
      {
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[0], *fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[1], *fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[2], *fsrc++);
        *fdst++ = *fsrc++;
      }
-  return samples;
 }
 
-static INLINE long
-conv_rgbF_linear_rgbF_gamma (unsigned char *src, 
+static INLINE void
+conv_rgbF_linear_rgbF_gamma (const Babl *conversion,unsigned char *src, 
                              unsigned char *dst, 
                              long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
 
    while (n--)
      {
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
-       *fdst++ = babl_linear_to_gamma_2_2f (*fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[0], *fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[1], *fsrc++);
+       *fdst++ = babl_trc_from_linear (trc[2], *fsrc++);
      }
-  return samples;
 }
 
 
-static INLINE long
-conv_rgbaF_gamma_rgbaF_linear (unsigned char *src, 
+static INLINE void
+conv_rgbaF_gamma_rgbaF_linear (const Babl *conversion,unsigned char *src, 
                                unsigned char *dst, 
                                long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
 
    while (n--)
      {
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[0], *fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[1], *fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[2], *fsrc++);
        *fdst++ = *fsrc++;
      }
-  return samples;
 }
 
-static INLINE long
-conv_rgbF_gamma_rgbF_linear (unsigned char *src, 
+static INLINE void
+conv_rgbF_gamma_rgbF_linear (const Babl *conversion,unsigned char *src, 
                              unsigned char *dst, 
                              long           samples)
 {
+   const Babl  *space = babl_conversion_get_destination_space (conversion);
+   const Babl **trc   = (void*)space->space.trc;
    float *fsrc = (float *) src;
    float *fdst = (float *) dst;
    int n = samples;
 
    while (n--)
      {
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
-       *fdst++ = babl_gamma_2_2_to_linearf (*fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[0], *fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[1], *fsrc++);
+       *fdst++ = babl_trc_to_linear (trc[2], *fsrc++);
      }
-  return samples;
 }
 
 #define o(src, dst) \
