@@ -145,8 +145,8 @@ gggl_float_to_index16 (float f)
   return (u.s >> 15) & ((1 << 17)-1);
 }
 
-static INLINE long
-conv_F_8 (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void
+conv_F_8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -159,12 +159,11 @@ conv_F_8 (unsigned char *src, unsigned char *dst, long samples)
       dst                   += 1;
       src                   += 4;
     }
-  return samples;
 }
 
 
-static INLINE long
-conv_F_8g (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void
+conv_F_8g (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -177,12 +176,11 @@ conv_F_8g (unsigned char *src, unsigned char *dst, long samples)
       dst                   += 1;
       src                   += 4;
     }
-  return samples;
 }
 
 
-static INLINE long __attribute__((unused))
-conv_8_F (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void __attribute__((unused))
+conv_8_F (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -194,12 +192,11 @@ conv_8_F (unsigned char *src, unsigned char *dst, long samples)
       dst             += 4;
       src             += 1;
     }
-  return samples;
 }
 
 
-static INLINE long
-conv_rgbaF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void
+conv_rgbaF_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -222,12 +219,11 @@ conv_rgbaF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
 
       src += 4;
     }
-  return samples;
 }
 
 
-static INLINE long __attribute__((unused))
-conv_rgbaF_rgba8 (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void __attribute__((unused))
+conv_rgbaF_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -253,23 +249,20 @@ conv_rgbaF_rgba8 (unsigned char *src, unsigned char *dst, long samples)
       src                   += 4;
       dst                   += 1;
     }
-  return samples;
 }
 
 #define conv_rgbaF_rgbP8    conv_rgbaF_rgba8
 
-static INLINE long __attribute__((unused))
-conv_rgbF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void __attribute__((unused))
+conv_rgbF_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_8g (src, dst, samples * 3);
-  return samples;
+  conv_F_8g (conversion, src, dst, samples * 3);
 }
 
-static INLINE long __attribute__((unused))
-conv_gaF_ga8 (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void __attribute__((unused))
+conv_gaF_ga8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_8 (src, dst, samples * 2);
-  return samples;
+  conv_F_8 (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbAF_rgbA8    conv_rgbaF_rgba8
@@ -277,8 +270,8 @@ conv_gaF_ga8 (unsigned char *src, unsigned char *dst, long samples)
 #define conv_gAF_gA8        conv_gaF_ga8
 
 
-static INLINE long
-conv_rgba8_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void
+conv_rgba8_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -300,11 +293,10 @@ conv_rgba8_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       dst             += 4;
       src             += 1;
     }
-  return samples;
 }
 
-static INLINE long
-conv_rgb8_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static INLINE void
+conv_rgb8_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -325,11 +317,10 @@ conv_rgb8_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       (*(float *) dst) = 1.0;
       dst             += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbAF_rgb8 (unsigned char *srcc,
+static void
+conv_rgbAF_rgb8 (const Babl *conversion,unsigned char *srcc,
                  unsigned char *dstc,
                  long           samples)
 {
@@ -356,11 +347,10 @@ conv_rgbAF_rgb8 (unsigned char *srcc,
       src += 4;
       dst += 3;
     }
-  return samples;
 }
 
-static long
-conv_bgrA8_rgba8 (unsigned char *srcc,
+static void
+conv_bgrA8_rgba8 (const Babl *conversion,unsigned char *srcc,
                   unsigned char *dstc,
                   long           samples)
 {
@@ -378,11 +368,10 @@ conv_bgrA8_rgba8 (unsigned char *srcc,
       src   += 4;
       dst   += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbaF_rgbAF (unsigned char *srcc,
+static void
+conv_rgbaF_rgbAF (const Babl *conversion,unsigned char *srcc,
                   unsigned char *dstc,
                   long           samples)
 {
@@ -400,11 +389,10 @@ conv_rgbaF_rgbAF (unsigned char *srcc,
       src   += 4;
       dst   += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbAF_rgbaF (unsigned char *srcc,
+static void
+conv_rgbAF_rgbaF (const Babl *conversion,unsigned char *srcc,
                   unsigned char *dstc,
                   long           samples)
 {
@@ -427,12 +415,11 @@ conv_rgbAF_rgbaF (unsigned char *srcc,
       src   += 4;
       dst   += 4;
     }
-  return samples;
 }
 
 
-static long
-conv_rgbAF_lrgba8 (unsigned char *srcc,
+static void
+conv_rgbAF_lrgba8 (const Babl *conversion,unsigned char *srcc,
                    unsigned char *dstc,
                    long           samples)
 {
@@ -458,7 +445,6 @@ conv_rgbAF_lrgba8 (unsigned char *srcc,
       src   += 4;
       dst   += 4;
     }
-  return samples;
 }
 
 #define conv_rgb8_rgbAF    conv_rgb8_rgbaF
