@@ -49,8 +49,8 @@
  *       gamma correction  (not really,. gamma correction belongs in seperate ops,.
  */
 
-static long
-conv_F_8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_F_8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -66,11 +66,10 @@ conv_F_8 (unsigned char *src, unsigned char *dst, long samples)
       dst += 1;
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_F_16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_F_16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -92,11 +91,10 @@ conv_F_16 (unsigned char *src, unsigned char *dst, long samples)
       dst += 2;
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_8_F (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_8_F (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -106,11 +104,10 @@ conv_8_F (unsigned char *src, unsigned char *dst, long samples)
       dst             += 4;
       src             += 1;
     }
-  return samples;
 }
 
-static long
-conv_16_F (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_16_F (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -120,11 +117,10 @@ conv_16_F (unsigned char *src, unsigned char *dst, long samples)
       dst             += 4;
       src             += 2;
     }
-  return samples;
 }
 
-static long
-conv_rgbaF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -146,11 +142,10 @@ conv_rgbaF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
         }
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_F_D (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_F_D (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -160,11 +155,10 @@ conv_F_D (unsigned char *src, unsigned char *dst, long samples)
       dst            += 8;
       src            += 4;
     }
-  return samples;
 }
 
-static long
-conv_D_F (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_D_F (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -174,11 +168,10 @@ conv_D_F (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 8;
     }
-  return samples;
 }
 
-static long
-conv_16_8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_16_8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -189,11 +182,10 @@ conv_16_8 (unsigned char *src, unsigned char *dst, long samples)
       dst                     += 1;
       src                     += 2;
     }
-  return samples;
 }
 
-static long
-conv_8_16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_8_16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -203,167 +195,149 @@ conv_8_16 (unsigned char *src, unsigned char *dst, long samples)
       dst                      += 2;
       src                      += 1;
     }
-  return samples;
 }
 
 
 /*********/
-static long
-conv_rgbaF_rgba8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_8 (src, dst, samples * 4);
-  return samples;
+  conv_F_8 (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgbF_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbF_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_8 (src, dst, samples * 3);
-  return samples;
+  conv_F_8 (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_gaF_ga8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gaF_ga8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_8 (src, dst, samples * 2);
-  return samples;
+  conv_F_8 (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbAF_rgbA8    conv_rgbaF_rgba8
 #define conv_gF_g8          conv_F_8
 #define conv_gAF_gA8        conv_gaF_ga8
 
-static long
-conv_rgbaF_rgba16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgba16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_16 (src, dst, samples * 4);
-  return samples;
+  conv_F_16 (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgbF_rgb16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbF_rgb16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_16 (src, dst, samples * 3);
-  return samples;
+  conv_F_16 (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_gaF_ga16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gaF_ga16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_16 (src, dst, samples * 2);
-  return samples;
+  conv_F_16 (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbAF_rgbA16    conv_rgbaF_rgba16
 #define conv_gF_g16          conv_F_16
 #define conv_gAF_gA16        conv_gaF_ga16
 
-static long
-conv_rgba8_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba8_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  return conv_8_F (src, dst, samples * 4) / 4;
+  conv_8_F (conversion, src, dst, samples * 4);
 }
 
 
-static long
-conv_rgb8_rgbF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgb8_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  return conv_8_F (src, dst, samples * 3) / 3;
+  conv_8_F (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_ga8_gaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_ga8_gaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  return conv_8_F (src, dst, samples * 2) / 2;
+  conv_8_F (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbA8_rgbAF    conv_rgba8_rgbaF
 #define conv_gA8_gAF        conv_ga8_gaF
 #define conv_g8_gF          conv_8_F
 
-static long
-conv_rgbaF_rgbaD (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgbaD (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_F_D (src, dst, samples * 4);
-  return samples;
+  conv_F_D (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgbaD_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaD_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_D_F (src, dst, samples * 4);
-  return samples;
+  conv_D_F (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgba16_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba16_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_F (src, dst, samples * 4);
-  return samples;
+  conv_16_F (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgb16_rgbF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgb16_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_F (src, dst, samples * 3);
-  return samples;
+  conv_16_F (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_ga16_gaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_ga16_gaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_F (src, dst, samples * 2);
-  return samples;
+  conv_16_F (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbA16_rgbAF    conv_rgba16_rgbaF
 #define conv_gA16_gAF        conv_ga16_gaF
 #define conv_g16_gF          conv_16_F
 
-static long
-conv_rgba16_rgba8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba16_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_8 (src, dst, samples * 4);
-  return samples;
+  conv_16_8 (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgb16_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgb16_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_8 (src, dst, samples * 3);
-  return samples;
+  conv_16_8 (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_ga16_ga8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_ga16_ga8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_16_8 (src, dst, samples * 2);
-  return samples;
+  conv_16_8 (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbA16_rgbA8    conv_rgba16_rgba8
 #define conv_gA16_gA8        conv_ga16_ga8
 #define conv_g16_g8          conv_16_8
 
-static long
-conv_rgba8_rgba16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba8_rgba16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_8_16 (src, dst, samples * 4);
-  return samples;
+  conv_8_16 (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgb8_rgb16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgb8_rgb16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_8_16 (src, dst, samples * 3);
-  return samples;
+  conv_8_16 (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_ga8_ga16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_ga8_ga16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
-  conv_8_16 (src, dst, samples * 2);
-  return samples;
+  conv_8_16 (conversion, src, dst, samples * 2);
 }
 
 #define conv_rgbA8_rgbA16    conv_rgba8_rgba16
@@ -372,8 +346,8 @@ conv_ga8_ga16 (unsigned char *src, unsigned char *dst, long samples)
 
 /* alpha conversions */
 
-static long
-conv_gaF_gAF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gaF_gAF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -388,11 +362,10 @@ conv_gaF_gAF (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 4;
     }
-  return samples;
 }
 
-static long
-conv_gAF_gaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gAF_gaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -407,13 +380,12 @@ conv_gAF_gaF (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 4;
     }
-  return samples;
 }
 
 /* alpha stripping and adding */
 
-static long
-conv_rgbaF_rgbF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -430,11 +402,10 @@ conv_rgbaF_rgbF (unsigned char *src, unsigned char *dst, long samples)
       src           += 4;
       src           += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -452,14 +423,13 @@ conv_rgbF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       *(float *) dst = 1.0;
       dst           += 4;
     }
-  return samples;
 }
 
 #define conv_rgbF_rgbAF    conv_rgbF_rgbaF
 
 
-static long
-conv_gaF_gF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gaF_gF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -470,11 +440,10 @@ conv_gaF_gF (unsigned char *src, unsigned char *dst, long samples)
       src         += 4;
       src         += 4;
     }
-  return samples;
 }
 
-static long
-conv_gF_gaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gF_gaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -486,7 +455,6 @@ conv_gF_gaF (unsigned char *src, unsigned char *dst, long samples)
       *(float *) dst = 1.0;
       dst           += 4;
     }
-  return samples;
 }
 
 #define conv_gF_gAF        conv_gF_gaF
@@ -495,8 +463,8 @@ conv_gF_gaF (unsigned char *src, unsigned char *dst, long samples)
 
 /* colorchannel dropping and adding */
 
-static long
-conv_gF_rgbF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gF_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -511,11 +479,10 @@ conv_gF_rgbF (unsigned char *src, unsigned char *dst, long samples)
         }
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_gaF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gaF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -533,7 +500,6 @@ conv_gaF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 4;
     }
-  return samples;
 }
 
 #define conv_gAF_rgbAF    conv_gaF_rgbaF
@@ -541,8 +507,8 @@ conv_gaF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
 /* other conversions coded for some optimisation reason or sumthin */
 
 
-static long
-conv_rgbaF_rgbA8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgbA8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -561,11 +527,10 @@ conv_rgbaF_rgbA8 (unsigned char *src, unsigned char *dst, long samples)
       dst++;
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbaF_rgb16 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbaF_rgb16 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -581,11 +546,10 @@ conv_rgbaF_rgb16 (unsigned char *src, unsigned char *dst, long samples)
         }
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbA16_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbA16_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -604,11 +568,10 @@ conv_rgbA16_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 2;
     }
-  return samples;
 }
 
-static long
-conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_gF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -624,13 +587,12 @@ conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       dst           += 4;
       src           += 4;
     }
-  return samples;
 }
 
 #define conv_gF_rgbAF conv_gF_rgbaF
 
 /*
-   static long
+   static void
    conv_rgb8_rgbaF (unsigned char *src,
                  unsigned char *dst,
                  int samples)
@@ -647,10 +609,9 @@ conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
         (*(float *) dst) = 1.0;
         dst += 4;
     }
-   return samples;
    }
 
-   static long
+   static void
    conv_g8_rgbaF (unsigned char *src,
                unsigned char *dst,
                int samples)
@@ -667,10 +628,9 @@ conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
         (*(float *) dst) = 1.0;
         dst += 4;
     }
-   return samples;
    }
 
-   static long
+   static void
    conv_rgb16_rgbaF (unsigned char *src,
                   unsigned char *dst,
                   int samples)
@@ -688,10 +648,9 @@ conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
         src += 2;
         dst += 4;
     }
-   return samples;
    }
 
-   static long
+   static void
    conv_gF_rgbaF (unsigned char *src,
                unsigned char *dst,
                int samples)
@@ -709,11 +668,10 @@ conv_gF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
         src += 4;
 
     }
-   return samples;
    }
  */
-static long
-conv_rgba8_rgbA8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba8_rgbA8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -738,11 +696,10 @@ conv_rgba8_rgbA8 (unsigned char *src, unsigned char *dst, long samples)
       dst += 4;
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgbA8_rgba8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbA8_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -768,11 +725,10 @@ conv_rgbA8_rgba8 (unsigned char *src, unsigned char *dst, long samples)
         }
       src += 4;
     }
-  return samples;
 }
 
-static long
-conv_rgb8_rgba8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgb8_rgba8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples-1;
   while (n--)
@@ -785,13 +741,12 @@ conv_rgb8_rgba8 (unsigned char *src, unsigned char *dst, long samples)
   dst[1] = src[1];
   dst[2] = src[2];
   dst[3] = 255;
-  return samples;
 }
 
 #define conv_rgb8_rgbA8    conv_rgb8_rgba8
 
-static long
-conv_rgba8_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgba8_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -803,11 +758,10 @@ conv_rgba8_rgb8 (unsigned char *src, unsigned char *dst, long samples)
       src   += 4;
       dst   += 3;
     }
-  return samples;
 }
 
-static long
-conv_rgbA8_rgb8 (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_rgbA8_rgb8 (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   long n = samples;
 
@@ -835,7 +789,6 @@ conv_rgbA8_rgb8 (unsigned char *src, unsigned char *dst, long samples)
         }
       src += 4;
     }
-  return samples;
 }
 
 #ifndef byteclamp
@@ -862,8 +815,8 @@ conv_rgbA8_rgb8 (unsigned char *src, unsigned char *dst, long samples)
 
 
 
-  static long
-conv_yuvaF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
+  static void
+conv_yuvaF_rgbaF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   float *src_f = (float *) src;
   float *dst_f = (float *) dst;
@@ -890,12 +843,11 @@ conv_yuvaF_rgbaF (unsigned char *src, unsigned char *dst, long samples)
       dst_f += 4;
       src_f += 4;
     }
-  return samples;
 }
 
 
-static long
-conv_yuvF_rgbF (unsigned char *src, unsigned char *dst, long samples)
+static void
+conv_yuvF_rgbF (const Babl *conversion,unsigned char *src, unsigned char *dst, long samples)
 {
   float *src_f = (float *) src;
   float *dst_f = (float *) dst;
@@ -921,7 +873,6 @@ conv_yuvF_rgbF (unsigned char *src, unsigned char *dst, long samples)
       dst_f += 3;
       src_f += 3;
     }
-  return samples;
 }
 
 int init (void);
