@@ -22,6 +22,15 @@
 #include <assert.h>
 #include <math.h>
 
+#ifndef BABL_LIBRARY
+#error "config.h must be included prior to util.h"
+#endif
+
+#ifndef HAVE_RINT
+# define rint(f)  (floor (((double) (f)) + 0.5))
+#endif
+
+
 #define BABL_PLANAR_SANITY  \
   {                         \
     assert(src_bands>0);    \
@@ -32,7 +41,7 @@
     assert(*dst);           \
     assert(n>0);            \
     assert(*src_pitch);     \
-  } 
+  }
 
 #define BABL_PLANAR_STEP          \
   {                               \
